==> nextcloud-25.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/circles/l10n/fi.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Piirit",
    "Circles' files" : "Piirien tiedostot",
    "No circles found" : "Piirejä ei löytynyt",
    "No files found for the selected circles" : "Valittujen piirien osalta ei löytynyt tiedostoja",
    "You created the circle {circle}" : "Loit piirin {circle}",
    "{author} created the circle {circle}" : "{author} loi piirin {circle}",
    "You deleted {circle}" : "Poistit piirin {circle}",
    "{author} deleted {circle}" : "{author} poisti piirin {circle}",
    "You linked {group} to {circle}" : "Linkitit ryhmän {group} piiriin {circle}",
    "{group} has been linked to {circle} by {author}" : "{author} linkitti ryhmän {group} piiriin {circle} ",
    "You unlinked {group} from {circle}" : "Poistit ryhmän {group} linkityksen piiriltä {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{author} poisti ryhmän {group} linkityksen piiriltä {circle}",
    "You sent a request to link {circle} with {remote}" : "Lähetit piirin {circle} linkityspyynnön kohteeseen {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} lähetti pyynnön linkittää piiri {circle} kohteen {remote} kanssa",
    "{remote} requested a link with {circle}" : "{remote} pyysi linkityksen piirille  {circle}",
    "The request to link {circle} with {remote} has been rejected" : "Pyyntö linkittää piiri {circle} kohteeseen {remote} on hylätty",
    "The request to link {remote} with {circle} has been canceled remotely" : "Pyyntö kohteen {remote} linkittämiseen piirin {circle} kanssa on peruttu kohteesta",
    "The request to link {circle} with {remote} has been accepted" : "Hyväksytty piirin {circle} linkityspyyntö kohteen {remote} kanssa",
    "You dismissed the request to link {remote} with {circle}" : "Hylkäsit pyynnön linkittää kohde {remote} piirin {circle} kanssa",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} hylkäsi pyynnön linkittää kohde {remote} piirin {circle} kanssa",
    "You canceled the request to link {circle} with {remote}" : "Peruit piirin {circle} linkityspyynnön kohteen {remote} kanssa",
    "{author} canceled the request to link {circle} with {remote}" : "{author} perui piirin {circle} linkityspyynnön kohteen {remote} kanssa",
    "You accepted the request to link {remote} with {circle}" : "Hyväksyit pyynnön linkittää kohde {remote} piirin {circle} kanssa",
    "{author} accepted the request to link {remote} with {circle}" : "{author} hyväksyi pyynnön linkittää kohde {remote} piirin {circle} kanssa",
    "A link between {circle} and {remote} is now up and running" : "Piirin {circle} ja kohteen {remote} linkitys on nyt käytössä",
    "The link between {circle} and {remote} has been shutdown remotely" : "Piirin {circle} ja kohteen {remote} linkitys on suljettu kohteesta.",
    "You closed the link between {circle} and {remote}" : "Suljit piirin {circle} ja kohteen {remote} linkityksen",
    "{author} closed the link between {circle} and {remote}" : "{author} sulki piirin {circle} ja kohteen {remote} linkityksen",
    "You joined {circle}" : "Liityit piiriin {circle}",
    "{member} joined {circle}" : "{member} liittyi piiriin {circle}",
    "You accepted the invitation to join {circle}" : "Hyväksyit kutsun liittyä piirin {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} hyväksyi kutsun liittyä piiriin {circle}",
    "You added {member} as member to {circle}" : "Lisäsit käyttäjän {member} jäsenenä piiriin {circle}",
    "You have been added as member to {circle} by {author}" : "{author} lisäsi sinut jäseneksi piiriin {circle}",
    "{member} has been added as member to {circle} by {author}" : "{member} lisättiin jäseneksi piiriin {circle} käyttäjän {author} toimesta",
    "You added {external} to {circle}" : "Lisäsit {external} piiriin {circle}",
    "{external} has been added to {circle} by {author}" : "{external} on lisätty piiriin {circle} käyttäjän {author} toimesta",
    "You accepted {member}'s request to join {circle}" : "Hyväksyit jäsenen {member} pyynnön liittyä piiriin {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Pyyntösi liittyä piiriin {circle} hyväksyttiin käyttäjän {author} toimesta",
    "{member}'s request to join {circle} has been accepted by {author}" : "Käyttäjän {member} pyyntö liittyä piiriin {circle} hyväksyttiin käyttäjän {author} toimesta",
    "You left {circle}" : "Poistuit piiristä {circle}",
    "{member} left {circle}" : "{member} poistui piiristä {circle}",
    "You declined the invitation to join {circle}" : "Kieltäydyit kutsusta liittyä piiriin {circle}",
    "{member} declined an invitation to join {circle}" : "{member} kieltäytyi kutsusta liittyä piiriin {circle}",
    "You cancelled your request to join {circle}" : "Peruit pyyntösi liittyä piiriin {circle}",
    "{member} cancelled his request to join {circle}" : "{member} perui pyyntönsä liittyä piiriin {circle}",
    "You removed {member} from {circle}" : "Poistit jäsenen {member} piiristä {circle}",
    "You have been removed from {circle} by {author}" : "Sinut poistettiin piiristä {circle} käyttäjän {author} toimesta",
    "{member} has been removed from {circle} by {author}" : "{member} poistettiin piiristä {circle} käyttäjän {author} toimesta",
    "You removed {external} from {circle}" : "Poistit {external} piiristä {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} poistettiin piiristä {circle} käyttäjän {author} toimesta",
    "You cancelled {member}'s invitation to join {circle}" : "Peruit jäsenen {member} kutsun liittyä piiriin {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} perui kutsusi liittyä piiriin {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} perui jäsenen {member} liittymiskutsun piiriin {circle}",
    "You dismissed {member}'s request to join {circle}" : "Hylkäsit jäsenen {member} liittymispyynnön piiriin {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "{author} hylkäsi liittymiskutsusi piiriin {circle}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} perui jäsenen {member} liittymispyynnön piiriin {circle}",
    "You invited {member} to join {circle}" : "Kutsuit jäsenen {member} liittymään piiriin {circle}",
    "You have been invited to join {circle} by {author}" : "Sinut kutsuttiin liittymään piiriin {circle} käyttäjän {author} toimesta",
    "{member} has been invited to join {circle} by {author}" : "{member} kutsuttiin liittymään piiriin {circle} käyttäjän {author} toimesta",
    "{author} changed your level in {circle} to %1$s" : "{author} muutti piirissä {circle} tasoksesi %1$s",
    "You sent a request to join {circle}" : "Lähetit pyynnön liittyä piiriin {circle}",
    "{member} sent a request to join {circle}" : "{member} lähetti pyynnön liittyä piiriin {circle}",
    "You are the new owner of {circle}" : "Olet piirin {circle} uusi omistaja",
    "{member} is the new owner of {circle}" : "{member} on piirin {circle} uusi omistaja",
    "Personal" : "Henkilökohtainen",
    "System" : "Järjestelmä",
    "Visible" : "Näkyvissä",
    "Open" : "Avaa",
    "Password Protected" : "Salasanasuojattu",
    "No Owner" : "Ei omistajaa",
    "Hidden" : "Piilotettu",
    "Local" : "Paikallinen",
    "Root" : "Juurihakemisto",
    "Federated" : "Federoitu",
    "Mount point" : "Liitospiste",
    "Nextcloud Group" : "Nextcloud-ryhmä",
    "Email Address" : "Sähköpostiosoite",
    "Contact" : "Yhteystieto",
    "Circle" : "Piiri",
    "Nextcloud App" : "Nextcloud-sovellus",
    "Member" : "Jäsen",
    "Moderator" : "Moderaattori",
    "Admin" : "Ylläpitäjä",
    "Owner" : "Omistaja",
    "%s shared »%s« with you." : "%s jakoi kohteen »%s« kanssasi.",
    "Password to access »%s«" : "Salasana kohteen »%s« käyttöön",
    "It is protected with the following password:" : "Se on suojattu seuraavalla salasanalla:",
    "%1$s via %2$s" : "%1$s palvelun %2$s kautta",
    "Click the button below to open it." : "Napsauta alla olevaa painiketta avataksesi sen.",
    "Open »%s«" : "Avaa »%s«",
    "Password to access files shared to you by %1$s" : "Salasana jäsenen %1$s kanssasi jakamiin tiedostoihin",
    "Password to access files" : "Salasana tiedostoihin",
    "%s shared multiple files with you." : "%s jakoi useita tiedostoja kanssasi.",
    "Circle not found" : "Piiriä ei löytynyt",
    "Circle not found " : "Piiriä ei löytynyt",
    "A circle with that name exists" : "Piirin nimi on jo olemassa",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Et voi käyttää Piirit-sovellusta ennen kuin ylläpitäjä on sallinut vähintään yhden tyypin piirin",
    "This member does not exist" : "Tämä jäsen ei ole olemassa",
    "Federated link not found" : "Federoitua linkkiä ei löytynyt",
    "This feature is not available for personal circles" : "Tämä ominaisuus ei ole henkilökohtaisten piirien käytössä",
    "The circle is not federated" : "Piiri ei ole federoitu",
    "You cannot join this circle" : "Et voi liittyä tähän piiriin",
    "This member is not a moderator" : "Tämä jäsen ei ole moderaattori",
    "Insufficient privileges" : "Riittämättömät oikeudet",
    "This member is the owner of the circle" : "Tämä jäsen on piirin omistaja",
    "You are already a member of this circle" : "Olet jo jäsenenä tässä piirissä",
    "You have been blocked from this circle" : "Sinut on estetty tästä piiristä",
    "You are now a member of the Circle \"%2$s\"" : "Olet nyt piirin \"%2$s\" jäsen",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "%1$s kutsui sinut piiriin \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s lähetti liittymispyynnön piiriin \"%2$s\"",
    "Accept" : "Hyväksy",
    "Refuse" : "Hylkää",
    "Leave the circle" : "Poistu piiristä",
    "%s" : "%s",
    "Personal Circle" : "Henkilökohtainen piiri",
    "You need a specify a type of circle" : "Sinun täytyy määritellä piirin tyyppi",
    "This member is not the owner of the circle" : "Tämä jäsen ei ole piirin omistaja",
    "This member is not an admin of the circle" : "Tämä jäsen ei ole piirin ylläpitäjä",
    "Group contains too many members" : "Ryhmä sisältää liian monta jäsentä",
    "This group does not exist" : "Tätä ryhmää ei ole olemassa",
    "This group is already linked to the circle" : "Tämä ryhmä on jo linkitetty piiriin",
    "You cannot edit level in a personal circle" : "Et voi muokata tasoa henkilökohtaisessa piirissä",
    "Group cannot be set as owner of a circle" : "Ryhmää ei voi asettaa piirin omistajaksi",
    "now" : "nyt",
    "Email format is not valid" : "Sähköpostin muoto ei ole kelvollinen",
    "This contact is not available" : "Tämä yhteystieto ei ole saatavilla",
    "%s shared a file with you." : "%s jakoi tiedoston kanssasi.",
    "This item is already shared with this circle" : "Tämä kohde on jo jaettu tämän piirin kanssa",
    "Could not find share" : "Jakoa ei löytynyt",
    "Bring cloud-users closer together." : "Tuo pilvikäyttäjät lähemmäksi toisiaan.",
    "No files in here" : "Täällä ei ole tiedostoja",
    "No entries found in this folder" : "Tästä kansiosta ei löytynyt tietueita",
    "Name" : "Nimi",
    "Size" : "Koko",
    "Modified" : "Muokattu",
    "Nextcloud User" : "Nextcloud-käyttäjä",
    "This user is already a member of the circle" : "Tämä käyttäjä on jo jäsenenä tässä piirissä",
    "The user is already a member of this circle" : "Käyttäjä on jo jäsenenä tässä piirissä",
    "The user has already been invited into this circle" : "Käyttäjä on jo kutsuttu tähän piiriin",
    "This user does not exist" : "Tätä käyttäjää ei ole olemassa"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/circles/l10n/fi.js <==
OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "Loit tiimin {circle}",
    "{author} created the team {circle}" : "{author} loi tiimin {circle}",
    "You deleted {circle}" : "Poistit piirin {circle}",
    "{author} deleted {circle}" : "{author} poisti piirin {circle}",
    "You removed {member} from {circle}" : "Poistit jäsenen {member} piiristä {circle}",
    "You joined {circle}" : "Liityit piiriin {circle}",
    "{member} joined {circle}" : "{member} liittyi piiriin {circle}",
    "You accepted the invitation to join {circle}" : "Hyväksyit kutsun liittyä piirin {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} hyväksyi kutsun liittyä piiriin {circle}",
    "You added {member} as member to {circle}" : "Lisäsit käyttäjän {member} jäsenenä piiriin {circle}",
    "You have been added as member to {circle} by {author}" : "{author} lisäsi sinut jäseneksi piiriin {circle}",
    "{member} has been added as member to {circle} by {author}" : "{member} lisättiin jäseneksi piiriin {circle} käyttäjän {author} toimesta",
    "You added {external} to {circle}" : "Lisäsit {external} piiriin {circle}",
    "{external} has been added to {circle} by {author}" : "{external} on lisätty piiriin {circle} käyttäjän {author} toimesta",
    "You accepted {member}'s request to join {circle}" : "Hyväksyit jäsenen {member} pyynnön liittyä piiriin {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Pyyntösi liittyä piiriin {circle} hyväksyttiin käyttäjän {author} toimesta",
    "{member}'s request to join {circle} has been accepted by {author}" : "Käyttäjän {member} pyyntö liittyä piiriin {circle} hyväksyttiin käyttäjän {author} toimesta",
    "You left {circle}" : "Poistuit piiristä {circle}",
    "{member} left {circle}" : "{member} poistui piiristä {circle}",
    "You declined the invitation to join {circle}" : "Kieltäydyit kutsusta liittyä piiriin {circle}",
    "{member} declined an invitation to join {circle}" : "{member} kieltäytyi kutsusta liittyä piiriin {circle}",
    "You cancelled your request to join {circle}" : "Peruit pyyntösi liittyä piiriin {circle}",
    "You have been removed from {circle} by {author}" : "Sinut poistettiin piiristä {circle} käyttäjän {author} toimesta",
    "{member} has been removed from {circle} by {author}" : "{member} poistettiin piiristä {circle} käyttäjän {author} toimesta",
    "You removed {external} from {circle}" : "Poistit {external} piiristä {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} poistettiin piiristä {circle} käyttäjän {author} toimesta",
    "You cancelled {member}'s invitation to join {circle}" : "Peruit jäsenen {member} kutsun liittyä piiriin {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} perui kutsusi liittyä piiriin {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} perui jäsenen {member} liittymiskutsun piiriin {circle}",
    "You dismissed {member}'s request to join {circle}" : "Hylkäsit jäsenen {member} liittymispyynnön piiriin {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "{author} hylkäsi liittymiskutsusi piiriin {circle}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} perui jäsenen {member} liittymispyynnön piiriin {circle}",
    "You invited {member} to join {circle}" : "Kutsuit jäsenen {member} liittymään piiriin {circle}",
    "You have been invited to join {circle} by {author}" : "Sinut kutsuttiin liittymään piiriin {circle} käyttäjän {author} toimesta",
    "{member} has been invited to join {circle} by {author}" : "{member} kutsuttiin liittymään piiriin {circle} käyttäjän {author} toimesta",
    "{author} changed your level in {circle} to %1$s" : "{author} muutti piirissä {circle} tasoksesi %1$s",
    "You sent a request to join {circle}" : "Lähetit pyynnön liittyä piiriin {circle}",
    "{member} sent a request to join {circle}" : "{member} lähetti pyynnön liittyä piiriin {circle}",
    "You are the new owner of {circle}" : "Olet piirin {circle} uusi omistaja",
    "{member} is the new owner of {circle}" : "{member} on piirin {circle} uusi omistaja",
    "Teams" : "Tiimit",
    "Personal" : "Henkilökohtainen",
    "System" : "Järjestelmä",
    "Visible" : "Näkyvissä",
    "Open" : "Avaa",
    "Invite" : "Kutsu",
    "Join request" : "Liittymispyyntö",
    "Friends" : "Kaverit",
    "Password protected" : "Salasanasuojattu",
    "No Owner" : "Ei omistajaa",
    "Hidden" : "Piilotettu",
    "Local" : "Paikallinen",
    "Root" : "Juurihakemisto",
    "Team invite" : "Tiimikutsu",
    "Federated" : "Federoitu",
    "Mount point" : "Liitospiste",
    "Nextcloud Account" : "Nextcloud-tili",
    "Nextcloud Group" : "Nextcloud-ryhmä",
    "Email address" : "Sähköpostiosoite",
    "Contact" : "Yhteystieto",
    "Team" : "Tiimi",
    "Nextcloud App" : "Nextcloud-sovellus",
    "Member" : "Jäsen",
    "Moderator" : "Moderaattori",
    "Admin" : "Ylläpitäjä",
    "Owner" : "Omistaja",
    "%s shared »%s« with you." : "%s jakoi kohteen »%s« kanssasi.",
    "Password to access »%s«" : "Salasana kohteen »%s« käyttöön",
    "It is protected with the following password:" : "Se on suojattu seuraavalla salasanalla:",
    "%1$s via %2$s" : "%1$s palvelun %2$s kautta",
    "Click the button below to open it." : "Napsauta alla olevaa painiketta avataksesi sen.",
    "Open »%s«" : "Avaa »%s«",
    "Password to access files shared to you by %1$s" : "Salasana jäsenen %1$s kanssasi jakamiin tiedostoihin",
    "Password to access files" : "Salasana tiedostoihin",
    "%s shared multiple files with you." : "%s jakoi useita tiedostoja kanssasi.",
    "Show all teams" : "Näytä kaikki tiimit",
    "Create a new team" : "Luo uusi tiimi",
    "Files" : "Tiedostot",
    "The team is not federated" : "Tiimi ei ole federoitu",
    "You cannot join this team" : "Et voi liittyä tähän tiimiin",
    "This member is not a moderator" : "Tämä jäsen ei ole moderaattori",
    "Insufficient privileges" : "Riittämättömät oikeudet",
    "This member does not exist" : "Tämä jäsen ei ole olemassa",
    "This member is the owner of the team" : "Tämä jäsen on tiimin omistaja",
    "%s (Team owned by %s)" : "%s (Tiimin omistaa %s)",
    "Accept" : "Hyväksy",
    "Refuse" : "Hylkää",
    "Leave the team" : "Poistu tiimistä",
    "%s" : "%s",
    "Personal team" : "Henkilökohtainen tiimi",
    "You have no permission to create a new team" : "Sinulla ei ole oikeutta luoda uutta tiimiä",
    "%s shared a file with you." : "%s jakoi tiedoston kanssasi.",
    "Open %s" : "Avaa %s",
    "Password to access content" : "Salasana sisällön käyttämiseksi",
    "Bring cloud-users closer together." : "Tuo pilvikäyttäjät lähemmäksi toisiaan.",
    "Failed to load teams" : "Tiimien lataaminen epäonnistui",
    "Try again" : "Yritä uudelleen",
    "No teams found" : "Tiimejä ei löytynyt",
    "Join or create teams to see them here." : "Liity tiimiin tai luo tiimi nähdäksesi ne täällä.",
    "Create your first team" : "Luo ensimmäinen tiimisi",
    "Loading…" : "Ladataan…",
    "More teams" : "Lisää tiimejä",
    "No files in here" : "Täällä ei ole tiedostoja",
    "No entries found in this folder" : "Tästä kansiosta ei löytynyt tietueita",
    "Name" : "Nimi",
    "Size" : "Koko",
    "Modified" : "Muokattu",
    "Shared to Circles" : "Jaettu piireille"
},
"nplurals=2; plural=(n != 1);");
